@@ -17,8 +17,9 @@ class UserService(ModelService):
     @permissions_required(['change_user'])
     def save(self, obj):
         _passwd = None
-        if obj.has_key('password') and obj['password'] != '_hidden_password_':
-            _passwd = obj['password']
+        if obj.has_key('password'):
+            if obj['password'] != '_hidden_password_':
+                _passwd = obj['password']
             del obj['password']
         pk = super(UserService, self).save(obj)
         if _passwd:
