@@ -3,11 +3,17 @@
 import inspect
 from django.conf.urls import patterns, url, include
 from django.contrib import admin
+from django.core.exceptions import ViewDoesNotExist
+from django.core.urlresolvers import reverse_lazy
+from django.views.generic.base import RedirectView
 from views import ApplicationView, SettingsView
 from models import Application
+from django.db import transaction
+
 
 admin.autodiscover()
 
+
 def application_url(regex_prefix, view):
     if not issubclass(view, ApplicationView):
         raise ValueError('Bad view type')
@@ -24,12 +30,20 @@ def application_url(regex_prefix, view):
         app.order = count
     else:
         app.order = 65534
-    app.active=True
+    app.active = True
     app.save()
     Application.objects.inc_apps_count()
     return url(regex, view.as_view(), name=view_name)
 
 
+@transaction.autocommit
+def first_app_redirect():
+    apps = Application.objects.all()
+    if len(apps) == 0:
+        raise ViewDoesNotExist('No user applications')
+    return  RedirectView.as_view(url=reverse_lazy(apps[0].view_name, kwargs={'path': ''}), permanent=False)
+
+
 urlpatterns = patterns('',
     url(r'^admin/', include(admin.site.urls)),
     application_url(r'^settings', SettingsView),
