@@ -15,5 +15,5 @@ class PartyRoleAdmin(admin.ModelAdmin):
 admin.site.register(PartyType, PartyTypeAdmin)
 admin.site.register(PartyRole, PartyRoleAdmin)
 
-refs.register(Reference(name=_('party_types'), group=_('parties'), url='enre/erp/party/views/PartyTypeView'))
-refs.register(Reference(name=_('party_roles'), group=_('parties'), url='enre/erp/party/views/PartyRoleView'))
\ No newline at end of file
+refs.register(Reference(name=_('Parties types'), group=_('Parties'), url='enre/erp/party/views/PartyTypeView'))
+refs.register(Reference(name=_('Parties roles'), group=_('Parties'), url='enre/erp/party/views/PartyRoleView'))
