@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*- 
 
 from enre.qx.services import ModelService
-from models import PartyType, PartyRole
+from models import PartyType, PartyRole, Party
 
 class PartyTypeService(ModelService):
     model = PartyType
@@ -9,3 +9,8 @@ class PartyTypeService(ModelService):
 
 class PartyRoleService(ModelService):
     model = PartyRole
+
+
+class PartyService(ModelService):
+    model = Party
+
