@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*- 
 
 from enre.qx.stores import ModelStore
-from models import PartyType, PartyRole
+from models import PartyType, PartyRole, Party
+from django.db.models import F
 
 class PartyTypeStore(ModelStore):
     query = PartyType.objects
@@ -9,3 +10,9 @@ class PartyTypeStore(ModelStore):
 
 class PartyRoleStore(ModelStore):
     query = PartyRole.objects
+
+
+class PartyStore(ModelStore):
+    query = Party.objects
+    related_fields = ['party_type__name']
+
